@@ -13,6 +13,7 @@ using Ascension::CEditDoc::CUndoManager;
 using namespace Manah;
 using namespace Manah::Windows;
 using namespace Armaiti;
+using namespace std;
 
 
 // CInsertOperation class implementation
@@ -30,7 +31,14 @@ bool CInsertOperation::Concat(COperationUnit* pOperationUnit) {
 
 ///	}̍Đ
 void CInsertOperation::Execute(CEditDoc* pDoc) {
-	pDoc->InsertText(0, m_pos, m_strText, OCF_VIRTUAL);
+	VIEW_POSITION	pos = pDoc->GetFirstViewPosition();
+	CView*			pView;
+
+	while(0 != (pView = pDoc->GetNextView(pos))) {
+		if(::GetFocus() == pView->m_hWnd)
+			break;
+	}
+	pDoc->InsertText(pView, m_pos, m_strText, OCF_VIRTUAL);
 }
 
 
@@ -67,7 +75,14 @@ bool CDeleteOperation::Concat(COperationUnit* pOperationUnit) {
 
 ///	폜̍Đ
 void CDeleteOperation::Execute(CEditDoc* pDoc) {
-	pDoc->DeleteText(0, m_posBegin, m_posEnd, OCF_VIRTUAL);
+	VIEW_POSITION	pos = pDoc->GetFirstViewPosition();
+	CView*			pView;
+
+	while(0 != (pView = pDoc->GetNextView(pos))) {
+		if(::GetFocus() == pView->m_hWnd)
+			break;
+	}
+	pDoc->DeleteText(pView, m_posBegin, m_posEnd, OCF_VIRTUAL);
 }
 
 
@@ -249,14 +264,11 @@ void CUndoManager::Undo() {
 // CEditDoc class implementation
 /////////////////////////////////////////////////////////////////////////////
 
-wchar_t* CEditDoc::m_arrBreakStrings[7]= {
-	L"", L"\n", L"\r", L"\r\n", L"\x0085", L"\x2028", L"\x2029"
-};
-wchar_t CEditDoc::m_wszBreakChars[6] = {			// U+0085 Ƀeg VC6 ŃG[ɂȂ
+const wchar_t CEditDoc::m_wszBreakChars[6] = {		// U+0085 Ƀeg VC6 ŃG[ɂȂ
 	0x000A, 0x000D, 0x0085, 0x2028, 0x2029, 0x0000	// (C99 ł 0x00A0 ȉ̕ \uxxxx `Ŏw肷邱Ƃ
 };													// oȂ炵 C++ Ƃ̊֘A͕s)
 
-std::map<UINT, CEditDoc*> CEditDoc::m_mapDocuments;
+map<UINT, CEditDoc*> CEditDoc::m_mapDocuments;
 
 ///	RXgN^
 CEditDoc::CEditDoc(Ascension::CEditController* pController /* = 0 */) :
@@ -277,7 +289,7 @@ CEditDoc::~CEditDoc() {
 	CloseDocument();
 	delete m_pUndoManager;
 	::KillTimer(0, m_nTimerId);
-	std::map<UINT, CEditDoc*>::iterator	it = CEditDoc::m_mapDocuments.find(m_nTimerId);
+	map<UINT, CEditDoc*>::iterator	it = CEditDoc::m_mapDocuments.find(m_nTimerId);
 	if(it != CEditDoc::m_mapDocuments.end())
 		CEditDoc::m_mapDocuments.erase(it);
 }
@@ -430,11 +442,16 @@ OperationStatus CEditDoc::DeleteCurrentFile() {
  *	@param posEnd	폜I_
  *	@param ocf		쌋tO
  *	@return			IɃLbguʒu
+ *	@throw EDocumentIsReadOnly	ǂݎp̂ƂX[
  */
 CCharPos CEditDoc::DeleteText(CView* pSender,
-		const CCharPos& posBegin, const CCharPos& posEnd, OperationConcatenationFlag ocf) {
+		const CCharPos& posBegin, const CCharPos& posEnd,
+		OperationConcatenationFlag ocf) throw(EDocumentIsReadOnly) {
 	AssertValid();
 
+	if(m_bReadOnly)
+		throw EDocumentIsReadOnly();
+
 	const CCharPos&	posABegin = min(posBegin, posEnd);	// n_
 	const CCharPos&	posAEnd = max(posBegin, posEnd);	// I_
 	wstring			strDeleted;							// 폜 (sɂȂƂ݂͌̉s})
@@ -456,13 +473,13 @@ CCharPos CEditDoc::DeleteText(CView* pSender,
 		CEditDocLineList::iterator	it = GetInternalLineIterator(posABegin.m_iLine), itNext;
 		CEditDocLineList::iterator	itFirstLine = it;
 		BreakType					btLastLine;
-		strDeleted += CEditDoc::m_arrBreakStrings[it->m_breakType];
+		strDeleted += CEditDoc::GetBreakString(it->m_breakType);
 		itNext = ++it;
 		for(unsigned long iLine = posABegin.m_iLine + 1; iLine < posAEnd.m_iLine + 1; ++iLine) {
 			strDeleted +=
 				((iLine != posAEnd.m_iLine) ? it->m_strLine : it->m_strLine.substr(0, posAEnd.m_iChar));
 			if(iLine != posAEnd.m_iLine)
-				strDeleted += m_arrBreakStrings[it->m_breakType];
+				strDeleted += GetBreakString(it->m_breakType);
 			++itNext;
 			assert(itNext != 0);
 			if(iLine == posAEnd.m_iLine) {	// 폜Is
@@ -492,7 +509,7 @@ CCharPos CEditDoc::DeleteText(CView* pSender,
 		m_oUpdateInfo.posBegin = min(posBegin, posEnd);
 		m_oUpdateInfo.posEnd = max(posBegin, posEnd);
 		m_oUpdateInfo.posResult = posABegin;
-		UpdateAllViews(0, 0, this);
+		UpdateAllViews(pSender, 0, this);
 	}
 	if(m_pEventListener != 0)
 		m_pEventListener->OnDocumentModified();
@@ -510,10 +527,10 @@ void CEditDoc::GetAllLines(wstring& strText) const {
 	unsigned long	cchAllLines = 0;
 
 	for(it = m_listLines.begin(); it != m_listLines.end(); ++it)
-		cchAllLines += it->m_strLine.length() + wcslen(CEditDoc::m_arrBreakStrings[it->m_breakType]);
+		cchAllLines += it->m_strLine.length() + CEditDoc::GetBreakString(it->m_breakType).length();
 	strText.reserve(cchAllLines);
 	for(it = m_listLines.begin(); it != m_listLines.end(); ++it)
-		strText += it->m_strLine + CEditDoc::m_arrBreakStrings[it->m_breakType];
+		strText += it->m_strLine + CEditDoc::GetBreakString(it->m_breakType);
 }
 
 ///	hLg̕ҏW̕ԂBsɂ݂͌̉sR[hgp
@@ -593,7 +610,7 @@ unsigned long CEditDoc::GetLineIndex(unsigned long iLine, bool bIncludeBreak) co
 	list<CEditDocLine>::const_iterator	it = m_listLines.begin();
 	for(unsigned long i = 0; i < iLine; ++it, ++i) {
 		iOffset += it->m_strLine.length();
-		iOffset += bIncludeBreak ? wcslen(CEditDoc::m_arrBreakStrings[it->m_breakType]) : 0;
+		iOffset += bIncludeBreak ? CEditDoc::GetBreakString(it->m_breakType).length() : 0;
 	}
 
 	return iOffset;
@@ -682,11 +699,16 @@ void CEditDoc::InitiateDocument() {
  *	@param strText	}镶
  *	@param ocf		쌋tO
  *	@return			ɃLbguʒu
+ *	@throw EDocumentIsReadOnly	ǂݎp̂ƂX[
  */
 CCharPos CEditDoc::InsertText(CView* pSender,
-		const CCharPos& pos, const wstring& strText, OperationConcatenationFlag ocf) {
+		const CCharPos& pos, const wstring& strText,
+		OperationConcatenationFlag ocf) throw(EDocumentIsReadOnly) {
 	AssertValid();
 
+	if(m_bReadOnly)
+		throw EDocumentIsReadOnly();
+
 	wstring::size_type	iLast = strText.find_first_of(CEditDoc::m_wszBreakChars);
 	wstring::size_type	iNext;
 	CCharPos			posResult;
@@ -773,7 +795,7 @@ CCharPos CEditDoc::InsertText(CView* pSender,
 		m_oUpdateInfo.posBegin = pos;
 		m_oUpdateInfo.posEnd = pos;
 		m_oUpdateInfo.posResult = posResult;
-		UpdateAllViews(0, 0, this);
+		UpdateAllViews(pSender, 0, this);
 	}
 
 	return posResult;
@@ -1074,9 +1096,14 @@ OperationStatus CEditDoc::MoveCurrentFile(const wchar_t* pwszDestination) {
 	return ops;
 }
 
-///	hD̎s
-void CEditDoc::Redo() {
+/**
+ *	hD̎s
+ *	@throw EDocumentIsReadOnly	ǂݎp̂ƂX[
+ */
+void CEditDoc::Redo() throw(EDocumentIsReadOnly) {
 	AssertValid();
+	if(m_bReadOnly)
+		throw EDocumentIsReadOnly();
 	m_pUndoManager->Redo();
 }
 
@@ -1189,7 +1216,7 @@ StreamStatus CEditDoc::SaveDocument(const wstring& strPathName,
 			it->m_breakType = bt;		// sR[h㏑
 		strLine = it->m_strLine;
 		if(iLine != cLine - 1)
-			strLine += m_arrBreakStrings[it->m_breakType];
+			strLine += GetBreakString(it->m_breakType);
 
 		// R[h̕ϊ
 		cchLine = GetLineLength(iLine);
@@ -1372,8 +1399,8 @@ bool CEditDoc::SendCurrentFile(bool bAsAttachment, bool bShowDialog /* = true */
 			wcsncpy(pwszContent + i, oLine.m_strLine.c_str(), oLine.m_strLine.length());
 			i += oLine.m_strLine.length();
 			if(iLine != m_listLines.size() - 1) {
-				wcscpy(pwszContent + i, m_arrBreakStrings[oLine.m_breakType]);
-				i += wcslen(m_arrBreakStrings[oLine.m_breakType]);
+				wcscpy(pwszContent + i, GetBreakString(oLine.m_breakType).c_str());
+				i += GetBreakString(oLine.m_breakType).length();
 			} else
 				break;
 		}
@@ -1457,14 +1484,19 @@ void CEditDoc::SetReadOnly(bool bReadOnly /* = true */) {
 ///	::SetTimer ̃R[obN֐B1000~bƂɌĂяoA
 ///	t@CvZXŕύXĂȂĎ
 void CALLBACK CEditDoc::TimerProc(HWND hWnd, UINT nMsg, UINT_PTR idEvent, DWORD dwTime) {
-	std::map<UINT, CEditDoc*>::iterator	it = CEditDoc::m_mapDocuments.find(idEvent);
+	map<UINT, CEditDoc*>::iterator	it = CEditDoc::m_mapDocuments.find(idEvent);
 
 	if(it != CEditDoc::m_mapDocuments.end())
 		it->second->CheckFileLastWriteTime();
 }
 
-///	AhD̎s
+/**
+ *	AhD̎s
+ *	@throw EDocumentIsReadOnly	ǂݎp̂ƂX[
+ */
 void CEditDoc::Undo() {
+	if(m_bReadOnly)
+		throw EDocumentIsReadOnly();
 	m_pUndoManager->Undo();
 	if(!m_bOnceUndoBufferCleared && m_pUndoManager->GetUndoBufferLength() == 0) {
 		m_bModified = false;
