@@ -28,6 +28,7 @@ public:
 
 	// RXgN^
 public:
+	///	RXgN^
 	explicit CCharPos(unsigned long iLine = 0,
 			unsigned long iChar = 0) : m_iLine(iLine), m_iChar(iChar) {
 	}
@@ -298,6 +299,14 @@ struct TUpdateInfo {
 	CCharPos	posResult;
 };
 
+///	hLgǂݎp̂ƂҏW悤ƂƃX[
+class EDocumentIsReadOnly {
+public:
+	wstring	GetDescription() const {
+		return L"Document is readonly. Any edit process is denied.";
+	}
+};
+
 ///	s̓e
 class CEditDocLine {
 	friend class CEditDoc;
@@ -355,13 +364,14 @@ const SaveDocumentOption	SDO_IGNORE_NOFITCHARS	= 0x0002;	///	ΉȂɑ΂Ċ̕ւ
  *	SĂ̍s̓eA엚AR[hy[WAsR[hȂǂB
  *	t@Cs
  *
- *	@see	CEditView, CEditController
+ *	@see	CEditView, CEditController, CEditPoint
  */
 class CEditDoc : public Manah::Windows::CDocument {
 
 	// CUndoManager class definition
 	/////////////////////////////////////////////////////////////////////////
 
+	///	AhDAhDǗ
 	class CUndoManager /*: public Manah::CManahObject*/ {
 		// f[^o
 	private:
@@ -389,6 +399,8 @@ class CEditDoc : public Manah::Windows::CDocument {
 	};
 
 	// f[^o
+public:
+	static const wchar_t	m_wszBreakChars[6];		// s̏W
 private:
 	bool						m_bIgnoreViews;	// OnUpdate ĂяoKvƂ true (t@CǂݍݓrȂ)
 	bool						m_bReadOnly;	// ǂݎp[h (ǂݍݎɐݒ肳s)
@@ -414,9 +426,6 @@ private:
 	mutable CEditDocLineList::iterator			m_itCache_;
 	mutable unsigned long						m_iLineCache;	// GetLineIterator LbVpf[^
 	mutable CEditDocLineList::const_iterator	m_itCache;
-public:
-	static wchar_t*		m_arrBreakStrings[7];	// BreakType -> s̃}bv
-	static wchar_t		m_wszBreakChars[6];		// s̏W (m_arrBreakStrings ƕ킵)
 
 	// RXgN^
 public:
@@ -445,21 +454,26 @@ public:
 	void				SetReadOnly(bool bReadOnly = true);								// ǂݎp[h̐ݒ
 
 	// ҏW
-	CCharPos	DeleteText(Manah::Windows::CView* pSender, const CCharPos& posBegin,	// w͈͂폜
-					const CCharPos& posEnd, OperationConcatenationFlag ocf);
-	CCharPos	InsertText(Manah::Windows::CView* pSender, const CCharPos& pos,			// wʒuɕ}
-					const std::wstring& strText, OperationConcatenationFlag ocf);	//  I_̈ʒuԂ
-	void		Redo();														// hD̎s
+	CCharPos	DeleteText(Manah::Windows::CView* pSender,					// w͈͂폜
+					const CCharPos& posBegin,
+					const CCharPos& posEnd,
+					OperationConcatenationFlag ocf) throw(EDocumentIsReadOnly);
+	CCharPos	InsertText(Manah::Windows::CView* pSender,					// wʒuɕ}
+					const CCharPos& pos,
+					const std::wstring& strText,
+					OperationConcatenationFlag ocf) throw(EDocumentIsReadOnly);
+	void		Redo() throw(EDocumentIsReadOnly);							// hD̎s
 	void		SetEventListener(IEditDocEventListener* pEventListener);	// CxgXi̐ݒ
-	void		Undo();														// AhD̎s
+	void		Undo() throw(EDocumentIsReadOnly);							// AhD̎s
 
 	// R[h
-	BreakType	GetBreakType() const;									// ݂̉sR[hԂ
-	UINT		GetCodePage() const;									// ݂̃R[hy[WԂ
-	static bool	IsAvailableCodePage(UINT nCodePage);					// ̃NXŗp\ȃR[hy[Wǂ
-	bool		IsCharCodeUnicode() const;								// gp̕R[h Unicode 
-	void		SetBreakType(BreakType bt) throw(invalid_argument);		// sR[h̐ݒ
-	void		SetCodePage(UINT nCodePage) throw(invalid_argument);	// R[hy[W̐ݒ
+	static wstring	GetBreakString(BreakType bt);
+	BreakType		GetBreakType() const;									// ݂̉sR[hԂ
+	UINT			GetCodePage() const;									// ݂̃R[hy[WԂ
+	static bool		IsAvailableCodePage(UINT nCodePage);					// ̃NXŗp\ȃR[hy[Wǂ
+	bool			IsCharCodeUnicode() const;								// gp̕R[h Unicode 
+	void			SetBreakType(BreakType bt) throw(invalid_argument);		// sR[h̐ݒ
+	void			SetCodePage(UINT nCodePage) throw(invalid_argument);	// R[hy[W̐ݒ
 
 	// t@C <-> hLg
 	// 3̃\bh͉炩̗RŎsꍇ́AG[̓e\_CAO\A
@@ -473,10 +487,11 @@ public:
 
 	// ɊJĂt@Cɑ΂鏈
 	OperationStatus	CopyCurrentFile(const wchar_t* pwszDestination);				// Rs[
-	OperationStatus	DeleteCurrentFile();											// ݔֈړ
+	OperationStatus	DeleteCurrentFile() throw(EDocumentIsReadOnly);					// ݔֈړ
 	bool			LockCurrentFile(FileOpenMode fom);								// bN
 	OperationStatus	MoveCurrentFile(const wchar_t* pwszDestination);				// ړ
 	bool			SendCurrentFile(bool bAsAttachment, bool bShowDialog = true);	// [֑M
+
 protected:
 	CEditDocLineList::iterator
 		GetInternalLineIterator(unsigned long iLine) const throw(out_of_range);	// const łȂsCe[^̎擾
@@ -494,6 +509,21 @@ public:
 // CEditDoc class inline implementation
 /////////////////////////////////////////////////////////////////////////////
 
+///	sR[h̉sԂ
+inline wstring CEditDoc::GetBreakString(BreakType bt) {
+	switch(bt) {
+	case BT_AUTO:	return L"";
+	case BT_LF:		return L"\n";
+	case BT_CR:		return L"\r";
+	case BT_CRLF:	return L"\r\n";
+	case BT_NEL:	return wstring(1, 0x0085);	// VC6
+	case BT_LS:		return L"\x2028";
+	case BT_PS:		return L"\x2029";
+	default:		assert(false);
+	}
+	return L"";	// ɂ͗Ȃ
+}
+
 ///	ݎgpĂsR[h擾
 inline BreakType CEditDoc::GetBreakType() const {
 	AssertValid();
