@@ -15,9 +15,17 @@ using namespace std;
 // CEditPoint class implementation
 /////////////////////////////////////////////////////////////////////////////
 
-///	RXgN^
-CEditPoint::CEditPoint(CEditView* pView, const CCharPos& pos)
-		: m_pView(pView), CCharPos(pos) {
+/**
+ *	RXgN^
+ *	@param pView	Ώۂ̃r[
+ */
+CEditPoint::CEditPoint(CEditView* pView) : m_pView(pView) {
+}
+
+///	fXgN^
+CEditPoint::~CEditPoint() {
+	if(m_pView != 0)
+		m_pView->ReleaseEditPoint(*this);
 }
 
 /**
@@ -26,8 +34,7 @@ CEditPoint::CEditPoint(CEditView* pView, const CCharPos& pos)
  */
 void CEditPoint::CharNext(unsigned long nOffset /* = 1 */) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	unsigned long	cLines = m_pView->GetDocument()->GetLineCount();
 	wstring			strLine = m_pView->GetDocument()->GetLine(m_iLine);
@@ -41,14 +48,9 @@ void CEditPoint::CharNext(unsigned long nOffset /* = 1 */) throw(EViewIsAlreadyI
 			strLine = m_pView->GetDocument()->GetLine(++m_iLine);
 			pwszLine = strLine.c_str();
 			m_iChar = 0;
-		} else {
-			while(true) {	// LbguƂ̏oȂ΂
-				if(++m_iChar == strLine.length())	// s
-					break;
-				if(CEditView::IsCharAcceptableCaret(pwszLine[m_iChar]))
-					break;
-			}
-		}
+		} else
+			// Lbg󂯎Ȃ΂
+			m_iChar += CEditView::MakeCaretPosValid(pwszLine, strLine.length(), ++m_iChar, false);
 	}
 	m_cxLast = m_pView->PosFromChar(*this).x
 				+ m_pView->m_ptScroll.x * m_pView->m_layoutInfo.nHScrollRatio * m_pView->GetAvgCharWidth()
@@ -61,8 +63,8 @@ void CEditPoint::CharNext(unsigned long nOffset /* = 1 */) throw(EViewIsAlreadyI
  */
 void CEditPoint::CharPrev(unsigned long nOffset /* = 1 */) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
+
 	wstring			strLine = m_pView->GetDocument()->GetLine(m_iLine);
 	const wchar_t*	pwszLine = strLine.c_str();
 
@@ -74,14 +76,9 @@ void CEditPoint::CharPrev(unsigned long nOffset /* = 1 */) throw(EViewIsAlreadyI
 			strLine = m_pView->GetDocument()->GetLine(--m_iLine);
 			pwszLine = strLine.c_str();
 			m_iChar = strLine.length();
-		} else {
-			while(true) {	// LbguƂ̏oȂ΂
-				if(--m_iChar == 0)	// s
-					break;
-				if(CEditView::IsCharAcceptableCaret(pwszLine[m_iChar]))
-					break;
-			}
-		}
+		} else
+			// Lbg󂯎Ȃ΂
+			m_iChar += CEditView::MakeCaretPosValid(pwszLine, strLine.length(), --m_iChar, true);
 	}
 	m_cxLast = m_pView->PosFromChar(*this).x
 				+ m_pView->m_ptScroll.x * m_pView->m_layoutInfo.nHScrollRatio * m_pView->GetAvgCharWidth()
@@ -91,32 +88,148 @@ void CEditPoint::CharPrev(unsigned long nOffset /* = 1 */) throw(EViewIsAlreadyI
 ///	ʒu\IuWFNgԂB߂l͌Ăяoō폜
 CEditPoint* CEditPoint::Clone() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
-	return new CEditPoint(m_pView, *this);
+	VERIFY_VIEW();
+
+	CEditPoint*	pClone = new CEditPoint(m_pView);
+	pClone->m_iLine = m_iLine;
+	pClone->m_iChar = m_iChar;
+	m_pView->m_setEditPoints.insert(pClone);
+	return pClone;
+}
+
+/**
+ *	wʒu܂ł̃eLXgϊ
+ *	@param cChars	1̈ʒu܂ł̕ (ł悢)
+ *	@param rct		ϊ̎
+ */
+void CEditPoint::Convert(long cChars, RangeConvertType rct) {
+	AssertValid();
+	VERIFY_VIEW();
+	// TODO: CEditPoint::Convert()
+}
+
+/**
+ *	wʒu܂ł̃eLXgϊ
+ *	@param pt	1̈ʒu
+ *	@param rct	ϊ̎
+ */
+void CEditPoint::Convert(const CEditPoint& pt, RangeConvertType rct) {
+	AssertValid();
+	VERIFY_VIEW();
+	// TODO: CEditPoint::Convert()
+}
+
+/**
+ *	wʒu܂ł̃eLXgNbv{[hɃRs[
+ *	@param cChars	Rs[镶 (ł悢)
+ */
+void CEditPoint::Copy(long cChars) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+	CClipboard::SetClipboardText(m_pView->m_hWnd, GetText(cChars).c_str());
+}
+
+/**
+ *	wʒu܂ł̃eLXgNbv{[hɃRs[
+ *	@param cChars	1̈ʒu܂ł̕
+ */
+void CEditPoint::Copy(const CEditPoint& pt) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+	CClipboard::SetClipboardText(m_pView->m_hWnd, GetText(pt).c_str());
+}
+
+/**
+ *	wʒu܂ł̃eLXg폜ăNbv{[hɃRs[
+ *	@param cChars	Rs[镶 (ł悢)
+ */
+void CEditPoint::Cut(long cChars) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+
+	if(m_pView->GetDocument()->IsReadOnly())
+		return;
+	CClipboard::SetClipboardText(m_pView->m_hWnd, GetText(cChars).c_str());
+	Delete(cChars);
+}
+
+/**
+ *	wʒu܂ł̃eLXg폜ăNbv{[hɃRs[
+ *	@param cChars	1̈ʒu܂ł̕ (ł悢)
+ */
+void CEditPoint::Cut(const CEditPoint& pt) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+
+	if(m_pView->GetDocument()->IsReadOnly())
+		return;
+	CClipboard::SetClipboardText(m_pView->m_hWnd, GetText(pt).c_str());
+	Delete(pt);
+}
+
+/**
+ *	wʒu܂ł̃eLXg폜
+ *	@param cChars	1̈ʒu܂ł̕ (ł悢)
+ */
+void CEditPoint::Delete(long cChars /* = 1 */) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+
+	if(m_pView->GetDocument()->IsReadOnly() || cChars == 0)
+		return;
+
+	CEditPoint	pt(m_pView);
+
+	pt.m_iLine = m_iLine;
+	pt.m_iChar = m_iChar;
+
+	if(cChars > 0)
+		pt.CharNext(cChars);
+	else {
+		while(cChars != 0) {
+			if(pt.m_iChar == 0) {
+				if(pt.m_iLine == 0)
+					break;
+				--pt.m_iLine;
+				pt.m_iChar = m_pView->GetDocument()->GetLineLength(pt.m_iLine);
+			} else
+				--pt.m_iChar;
+		}
+	}
+	Delete(pt);
+}
+
+/**
+ *	wʒu܂ł̃eLXg폜
+ *	@param pt	1̈ʒu
+ */
+void CEditPoint::Delete(const CEditPoint& pt) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+
+	if(m_pView->GetDocument()->IsReadOnly())
+		return;
+	*this = m_pView->GetDocument()->DeleteText(m_pView, *this, pt, OCF_PREVENTALL);
 }
 
 ///	_r[̒ɗ悤ɃXN[
 void CEditPoint::EnsureCentered() throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 	// TODO: CEditPoint::EnsureCentered()
 }
 
 ///	_ɂȂ悤Ƀr[XN[
 void CEditPoint::EnsureVisible() throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 	// TODO: CEditPoint::EnsureVisible()
 }
 
 ///	hLg̐擪̕Ԃ
 unsigned long CEditPoint::GetAbsoluteCharOffset() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	unsigned long	nOffset = 0;
 	LineIterator	itLines = m_pView->GetDocument()->GetLineIterator(0);
@@ -135,24 +248,21 @@ unsigned long CEditPoint::GetAbsoluteCharOffset() const throw(EViewIsAlreadyInav
 ///	ԍԂ
 unsigned long CEditPoint::GetCharNumber() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 	return m_iChar;
 }
 
 ///	\̗ԍԂ
 unsigned long CEditPoint::GetColumnNumber() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 	return m_pView->ColumnFromChar(*this);
 }
 
 ///	_s̒Ԃ
 unsigned long CEditPoint::GetLineLength() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 	Normalize();
 	return m_pView->GetDocument()->GetLineLength(m_iLine);
 }
@@ -160,12 +270,68 @@ unsigned long CEditPoint::GetLineLength() const throw(EViewIsAlreadyInavailable)
 ///	sԍԂ
 unsigned long CEditPoint::GetLineNumber() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 	Normalize();
 	return m_iLine;
 }
 
+/**
+ *	͈͓̃eLXgԂ
+ *	@param cChars	1̈ʒu܂ł̕ (ł悢)
+ */
+wstring CEditPoint::GetText(long cChars) const throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+
+	Normalize();
+	if(cChars == 0)
+		return L"";
+
+	const CEditDoc*	pDoc = m_pView->GetDocument();
+	wostringstream	ssText;
+
+	while(true) {
+	}
+}
+
+/**
+ *	͈͓̃eLXgԂ
+ *	@param pt	1̈ʒu
+ */
+wstring CEditPoint::GetText(const CEditPoint& pt) const throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+
+	Normalize();
+	if(*this == pt)
+		return L"";
+
+	const CEditDoc*		pDoc = m_pView->GetDocument();
+	const CEditPoint&	posStart = std::min(*this, pt);
+	const CEditPoint&	posEnd = std::max(*this, pt);
+
+	if(posStart.m_iLine == posEnd.m_iLine)	// 1s̏ꍇ
+		return pDoc->GetLine(posEnd.m_iLine).substr(
+			posStart.m_iChar, posEnd.m_iChar - posStart.m_iChar);
+	else {	// s̏ꍇ
+		wostringstream	ssText;
+		unsigned long	iLine = posStart.m_iLine;
+		LineIterator	itLines = pDoc->GetLineIterator(iLine);
+
+		while(true) {
+			if(iLine == posStart.m_iLine)	// 擪s
+				ssText << itLines->GetLine().substr(posStart.m_iChar);
+			else if(iLine == posEnd.m_iLine)	// ŏIs
+				ssText << itLines->GetLine().substr(0, posEnd.m_iChar);
+			else
+				ssText << itLines->GetLine() << CEditDoc::GetBreakString(itLines->GetBreakType());
+			++iLine;
+			++itLines;
+		}
+		return ssText.str();
+	}
+}
+
 /**
  *	_̈ʒuɕ}B݈ʒu͓͕i߂
  *	@param strText	}eLXg
@@ -174,18 +340,17 @@ unsigned long CEditPoint::GetLineNumber() const throw(EViewIsAlreadyInavailable)
 void CEditPoint::Insert(const wstring& strText,
 		Ascension::OperationConcatenationFlag ocf) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
-	CCharPos	posResult = m_pView->GetDocument()->InsertText(m_pView, *this, strText, ocf);
-	m_iLine = posResult.m_iLine;
-	m_iChar = posResult.m_iChar;
+	VERIFY_VIEW();
+
+	if(m_pView->GetDocument()->IsReadOnly())
+		return;
+	*this = m_pView->GetDocument()->InsertText(m_pView, *this, strText, ocf);
 }
 
 ///	݈ʒuhLg̏I[ł邩ǂԂ
 bool CEditPoint::IsAtEndOfDocument() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	CEditDoc*	pDoc = m_pView->GetDocument();
 
@@ -198,8 +363,7 @@ bool CEditPoint::IsAtEndOfDocument() const throw(EViewIsAlreadyInavailable) {
 ///	݈ʒusł邩ǂԂ
 bool CEditPoint::IsAtEndOfLine() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 	Normalize();
 	return m_pView->GetDocument()->GetLineLength(m_iLine) == m_iChar;
 }
@@ -207,8 +371,7 @@ bool CEditPoint::IsAtEndOfLine() const throw(EViewIsAlreadyInavailable) {
 ///	݈ʒuhLg̐擪ł邩ǂԂ
 bool CEditPoint::IsAtStartOfDocument() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 	Normalize();
 	return m_iLine == 0 && m_iChar == 0;
 }
@@ -216,8 +379,7 @@ bool CEditPoint::IsAtStartOfDocument() const throw(EViewIsAlreadyInavailable) {
 ///	݈ʒusł邩ǂԂ
 bool CEditPoint::IsAtStartOfLine() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 	Normalize();
 	return m_iChar == 0;
 }
@@ -228,8 +390,7 @@ bool CEditPoint::IsAtStartOfLine() const throw(EViewIsAlreadyInavailable) {
  */
 void CEditPoint::LineDown(unsigned long cLines /* = 1 */) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	unsigned long	cLines_ = m_pView->GetDocument()->GetLineCount();
 
@@ -244,8 +405,7 @@ void CEditPoint::LineDown(unsigned long cLines /* = 1 */) throw(EViewIsAlreadyIn
  */
 void CEditPoint::LineUp(unsigned long cLines /* = 1 */) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	Normalize();
 	m_iLine = (m_iLine < cLines) ? 0 : m_iLine - cLines;
@@ -258,8 +418,7 @@ void CEditPoint::LineUp(unsigned long cLines /* = 1 */) throw(EViewIsAlreadyInav
  */
 void CEditPoint::MoveToAbsoluteCharOffset(unsigned long nOffset) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	const CEditDoc*	pDoc = m_pView->GetDocument();
 	unsigned long	cRead = 0;
@@ -282,8 +441,7 @@ void CEditPoint::MoveToAbsoluteCharOffset(unsigned long nOffset) throw(EViewIsAl
 ///	hLg̏I[Ɉړ
 void CEditPoint::MoveToEndOfDocument() throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	const CEditDoc*	pDoc = m_pView->GetDocument();
 	m_iLine = pDoc->GetLineCount() - 1;
@@ -293,8 +451,7 @@ void CEditPoint::MoveToEndOfDocument() throw(EViewIsAlreadyInavailable) {
 ///	sɈړ
 void CEditPoint::MoveToEndOfLine() throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	m_iLine = std::min(m_iLine, m_pView->GetDocument()->GetLineCount() - 1);
 	m_iChar = m_pView->GetDocument()->GetLineLength(m_iLine);
@@ -303,8 +460,7 @@ void CEditPoint::MoveToEndOfLine() throw(EViewIsAlreadyInavailable) {
 ///	̃ubN}[Ns̍sɈړ
 void CEditPoint::MoveToNextBookmark() throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	unsigned long	iLine;
 	unsigned long	cLines = m_pView->GetDocument()->GetLineCount();
@@ -334,8 +490,7 @@ void CEditPoint::MoveToNextBookmark() throw(EViewIsAlreadyInavailable) {
  */
 void CEditPoint::MoveToPoint(const CCharPos& pos) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	m_iLine = pos.m_iLine;
 	m_iChar = pos.m_iChar;
@@ -345,8 +500,7 @@ void CEditPoint::MoveToPoint(const CCharPos& pos) throw(EViewIsAlreadyInavailabl
 ///	ÕubN}[Ns̍sɈړ
 void CEditPoint::MoveToPrevBookmark() throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	unsigned long	iLine = m_iLine - 1;
 
@@ -375,8 +529,7 @@ void CEditPoint::MoveToPrevBookmark() throw(EViewIsAlreadyInavailable) {
 ///	hLg̐擪Ɉړ
 void CEditPoint::MoveToStartOfDocument() throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	m_iLine = m_iChar = 0;
 }
@@ -384,8 +537,7 @@ void CEditPoint::MoveToStartOfDocument() throw(EViewIsAlreadyInavailable) {
 ///	sɈړ
 void CEditPoint::MoveToStartOfLine() throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	m_iLine = std::min(m_iLine, m_pView->GetDocument()->GetLineCount() - 1);
 	m_iChar = 0;
@@ -394,11 +546,76 @@ void CEditPoint::MoveToStartOfLine() throw(EViewIsAlreadyInavailable) {
 ///	ʒuɈړ (const \bh悭Ăяô const ɂĂ)
 void CEditPoint::Normalize() const throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
-	const_cast<CEditPoint*>(this)->m_iLine = std::min(m_iLine, m_pView->GetDocument()->GetLineCount() - 1);
-	const_cast<CEditPoint*>(this)->m_iChar = std::min(m_iChar, m_pView->GetDocument()->GetLineLength(m_iLine));
+	const_cast<CEditPoint*>(this)->m_iLine =
+		std::min(m_iLine, m_pView->GetDocument()->GetLineCount() - 1);
+	const_cast<CEditPoint*>(this)->m_iChar =
+		std::min(m_iChar, m_pView->GetDocument()->GetLineLength(m_iLine));
+}
+
+/**
+ *	͈͓̃eLXgNbv{[h̓eŒu
+ *	@param cChars	1̈ʒu܂ł̕ (ł悢)
+ */
+void CEditPoint::Paste(long cChars /* = 0 */) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+	// TODO: CEditPoint::Paste()
+}
+
+/**
+ *	͈͓̃eLXgNbv{[h̓eŒu
+ *	@param pt	1̈ʒu
+ */
+void CEditPoint::Paste(const CEditPoint& pt) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+	// TODO: CEditPoint::Paste()
+}
+
+/**
+ *	͈͓̃eLXgXy[XCfg
+ *	@param pt		1̈ʒu
+ *	@param nLevel	Cfgx
+ */
+void CEditPoint::SpaceIndent(const CEditPoint& pt, long nLevel /* = 1 */) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+	// TODO: CEditPoint::SpaceIndent()
+}
+
+/**
+ *	͈͓̃eLXg̃Xy[X^uɕϊ
+ *	@param cChars		1̈ʒu܂ł̕ (ł悢)
+ *	@param bUntabify	^uXy[Xɕϊꍇ true
+ */
+void CEditPoint::Tabify(long cChars, bool bUntabify /* = false */) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+	// TODO: CEditPoint::Tabify()
+}
+
+/**
+ *	͈͓̃eLXg̃Xy[X^uɕϊ
+ *	@param pt	1̈ʒu
+ *	@param bUntabify	^uXy[Xɕϊꍇ true
+ */
+void CEditPoint::Tabify(const CEditPoint& pt, bool bUntabify /* = false */) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+	// TODO: CEditPoint::Tabify()
+}
+
+/**
+ *	͈͓̃eLXg^uCfg
+ *	@param pt		1̈ʒu
+ *	@param nLevel	Cfgx
+ */
+void CEditPoint::TabIndent(const CEditPoint& pt, long nLevel /* = 1 */) throw(EViewIsAlreadyInavailable) {
+	AssertValid();
+	VERIFY_VIEW();
+	// TODO: CEditPoint::TabIndent()
 }
 
 /**
@@ -407,8 +624,7 @@ void CEditPoint::Normalize() const throw(EViewIsAlreadyInavailable) {
  */
 void CEditPoint::WordEndNext(unsigned long cWords /* = 1 */) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	Normalize();
 	// TODO: CEditPoint::WordEndNext()
@@ -420,8 +636,7 @@ void CEditPoint::WordEndNext(unsigned long cWords /* = 1 */) throw(EViewIsAlread
  */
 void CEditPoint::WordEndPrev(unsigned long cWords /* = 1 */) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	Normalize();
 	// TODO: CEditPoint::WordEndPrev()
@@ -433,8 +648,7 @@ void CEditPoint::WordEndPrev(unsigned long cWords /* = 1 */) throw(EViewIsAlread
  */
 void CEditPoint::WordNext(unsigned long cWords /* = 1 */) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	Normalize();
 	// TODO: CEditPoint::WordNext()
@@ -446,8 +660,7 @@ void CEditPoint::WordNext(unsigned long cWords /* = 1 */) throw(EViewIsAlreadyIn
  */
 void CEditPoint::WordPrev(unsigned long cWords /* = 1 */) throw(EViewIsAlreadyInavailable) {
 	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
+	VERIFY_VIEW();
 
 	Normalize();
 	// TODO: CEditPoint::WordPrev()
@@ -456,20 +669,12 @@ void CEditPoint::WordPrev(unsigned long cWords /* = 1 */) throw(EViewIsAlreadyIn
 
 // CEditRange class implementation
 /////////////////////////////////////////////////////////////////////////////
-
+#if 0
 ///	RXgN^
 CEditRange::CEditRange(CEditView* pView, const CCharPos& posStart, const CCharPos& posEnd)
 		: m_pView(pView), m_pAnchorPoint(new CEditPoint(pView, posStart)), m_pActivePoint(new CEditPoint(pView, posEnd)) {
 }
 
-///	͈͓̃eLXgNbv{[hɃRs[ (͈͂ł)
-void CEditRange::Copy() const throw(EViewIsAlreadyInavailable) {
-	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
-	CClipboard::SetClipboardText(m_pView->m_hWnd, GetText().c_str());
-}
-
 ///	͈͓̃eLXg폜B̃\bh͏I_n_̈ʒuɈړ
 void CEditRange::Delete() throw(EViewIsAlreadyInavailable) {
 	AssertValid();
@@ -482,42 +687,6 @@ void CEditRange::Delete() throw(EViewIsAlreadyInavailable) {
 	m_pView->GetDocument()->DeleteText(m_pView, *m_pAnchorPoint, *m_pActivePoint, OCF_PREVENTALL);
 }
 
-///	͈͓̃eLXgԂ
-wstring CEditRange::GetText() const throw(EViewIsAlreadyInavailable) {
-	AssertValid();
-	if(!IsAvailable())
-		throw EViewIsAlreadyInavailable();
-
-	if(IsEmpty())
-		return L"";
-	const_cast<CEditRange*>(this)->Normalize();
-
-	const CEditDoc*		pDoc = m_pView->GetDocument();
-	const CEditPoint&	posStart = std::min(*m_pAnchorPoint, *m_pActivePoint);
-	const CEditPoint&	posEnd = std::max(*m_pAnchorPoint, *m_pActivePoint);
-
-	if(m_pAnchorPoint->m_iLine == m_pActivePoint->m_iLine) {	// 1s̏ꍇ
-		return pDoc->GetLine(posEnd.m_iLine).substr(
-			posStart.m_iChar, posEnd.m_iChar - posStart.m_iChar);
-	} else {	// s̏ꍇ
-		wostringstream	ssText;
-		unsigned long	iLine = posStart.m_iLine;
-		LineIterator	itLines = pDoc->GetLineIterator(iLine);
-
-		while(true) {
-			if(iLine == posStart.m_iLine)	// 擪s
-				ssText << itLines->GetLine().substr(posStart.m_iChar);
-			else if(iLine == posEnd.m_iLine) {	// ŏIs
-				ssText << itLines->GetLine().substr(0, posEnd.m_iChar);
-			} else
-				ssText << itLines->GetLine() << CEditDoc::m_arrBreakStrings[itLines->GetBreakType()];
-			++iLine;
-			++itLines;
-		}
-		return ssText.str();
-	}
-}
-
 ///	͈͓eLXgLs^CY
 void CEditRange::MakeCapitalized() throw(EViewIsAlreadyInavailable) {
 	AssertValid();
@@ -660,6 +829,6 @@ void CEditRange::Replace(const wstring& strText) throw(EViewIsAlreadyInavailable
 	m_pActivePoint->m_iLine = posResult.m_iLine;
 	m_pActivePoint->m_iChar = posResult.m_iChar;
 }
-
+#endif
 
 /* [EOF] */
\ No newline at end of file
