@@ -10,6 +10,7 @@
 #include "..\..\Manah\TextConverter.h"
 #include "..\..\Armaiti\DraggingTextDataObject.h"
 #include "LineLayout.h"
+#include "TextSearcher.h"
 #include "KeyMacroPlayer.h"
 #include "AutoCompleteWnd.h"
 #include <set>
@@ -22,7 +23,6 @@ class CEditController;
 class CLineLayoutInfo;
 class CLineLayoutManager;
 class CEditPoint;
-class CEditRange;
 class CKeywordManager;
 class CKeyMacroPlayer;
 class CAutoCompleteWnd;
@@ -31,48 +31,63 @@ class CAutoCompleteWnd;
 // Miscellaneous
 /////////////////////////////////////////////////////////////////////////////
 
-#define WM_REDO								(WM_APP + 1)
-#define WM_SELECTALL						(WM_APP + 2)
-#define ID_SHOWUNICODECONTROLCHARS			(WM_APP + 3)
-#define ID_INSERTUNICODECONTROLCHAR_LRM		(WM_APP + 4)
-#define ID_INSERTUNICODECONTROLCHAR_RLM		(WM_APP + 5)
-#define ID_INSERTUNICODECONTROLCHAR_ZWJ		(WM_APP + 6)
-#define ID_INSERTUNICODECONTROLCHAR_ZWNJ	(WM_APP + 7)
-#define ID_INSERTUNICODECONTROLCHAR_LRE		(WM_APP + 8)
-#define ID_INSERTUNICODECONTROLCHAR_RLE		(WM_APP + 9)
-#define ID_INSERTUNICODECONTROLCHAR_LRO		(WM_APP + 10)
-#define ID_INSERTUNICODECONTROLCHAR_RLO		(WM_APP + 11)
-#define ID_INSERTUNICODECONTROLCHAR_PDF		(WM_APP + 12)
-#define ID_INSERTUNICODECONTROLCHAR_NADS	(WM_APP + 13)
-#define ID_INSERTUNICODECONTROLCHAR_NODS	(WM_APP + 14)
-#define ID_INSERTUNICODECONTROLCHAR_ASS		(WM_APP + 15)
-#define ID_INSERTUNICODECONTROLCHAR_ISS		(WM_APP + 16)
-#define ID_INSERTUNICODECONTROLCHAR_AAFS	(WM_APP + 17)
-#define ID_INSERTUNICODECONTROLCHAR_IAFS	(WM_APP + 18)
-#define ID_INSERTUNICODECONTROLCHAR_RS		(WM_APP + 19)
-#define ID_INSERTUNICODECONTROLCHAR_US		(WM_APP + 20)
-#define ID_INSERTUNICODESPACECHAR_NEL		(WM_APP + 29)
-#define ID_INSERTUNICODESPACECHAR_NBSP		(WM_APP + 30)
-#define ID_INSERTUNICODESPACECHAR_U1680		(WM_APP + 31)
-#define ID_INSERTUNICODESPACECHAR_U2000		(WM_APP + 32)
-#define ID_INSERTUNICODESPACECHAR_U2001		(WM_APP + 33)
-#define ID_INSERTUNICODESPACECHAR_U2002		(WM_APP + 34)
-#define ID_INSERTUNICODESPACECHAR_U2003		(WM_APP + 35)
-#define ID_INSERTUNICODESPACECHAR_U2004		(WM_APP + 36)
-#define ID_INSERTUNICODESPACECHAR_U2005		(WM_APP + 37)
-#define ID_INSERTUNICODESPACECHAR_U2006		(WM_APP + 38)
-#define ID_INSERTUNICODESPACECHAR_U2007		(WM_APP + 39)
-#define ID_INSERTUNICODESPACECHAR_U2008		(WM_APP + 40)
-#define ID_INSERTUNICODESPACECHAR_U2009		(WM_APP + 41)
-#define ID_INSERTUNICODESPACECHAR_U200A		(WM_APP + 42)
-#define ID_INSERTUNICODESPACECHAR_U200B		(WM_APP + 43)
-#define ID_INSERTUNICODESPACECHAR_LS		(WM_APP + 44)
-#define ID_INSERTUNICODESPACECHAR_PS		(WM_APP + 45)
-#define ID_INSERTUNICODESPACECHAR_U202F		(WM_APP + 46)
-#define ID_INSERTUNICODESPACECHAR_U3000		(WM_APP + 47)
-#define ID_TOGGLEIMESTATUS					(WM_APP + 48)
-#define ID_RECOMPOSITIONIME					(WM_APP + 49)
-#define ID_SHOWRTL							(WM_APP + 50)
+///	ǐՒ Unicode ̃o[W
+#define ASCENSION_UNICODE_VERSION	0x0400
+
+///	ReLXgj[Ȃǂ ID
+enum {
+	WM_REDO	= WM_APP + 1,		///	ɖ߂
+	WM_SELECTALL,				///	SđI
+	ID_SHOWUNICODECONTROLCHARS,	///	Unicode 䕶̕\
+	ID_SHOWRTL,					///	E獶ɓǂ
+	ID_TOGGLEIMESTATUS,			///	IME J/
+	ID_RECOMPOSITIONIME,		///	ĕϊ
+
+	ID_INSERT_LRM,		///	LRM (Left-to-right mark)
+	ID_INSERT_RLM,		///	RLM (Right-to-left mark)
+	ID_INSERT_ZWJ,		///	ZWJ (Zero width joiner)
+	ID_INSERT_ZWNJ,		///	ZWNJ (Zero width non-joiner)
+	ID_INSERT_LRE,		///	LRE (Left-to-right embedding)
+	ID_INSERT_RLE,		///	RLE (Right-to-left embedding)
+	ID_INSERT_LRO,		///	LRO (Left-to-right override)
+	ID_INSERT_RLO,		///	RLO (Right-to-left override)
+	ID_INSERT_PDF,		///	PDF (Pop directional formatting)
+	ID_INSERT_WJ,		///	WJ (Word Joiner)
+	ID_INSERT_U2061,	///	U+2061 (Function Application)
+	ID_INSERT_U2062,	///	U+2062 (Invisible Times)
+	ID_INSERT_U2063,	///	U+2063 (Invisible Separator)
+/*	ID_INSERT_NADS,		///	NADS (National digit shapes)	<- 񐄏vf炵
+	ID_INSERT_NODS,		///	NODS (Nominal digit shapes)
+	ID_INSERT_ASS,		///	ASS (Activate symmetric swapping)
+	ID_INSERT_ISS,		///	ISS (Inhibit symmetric swapping)
+	ID_INSERT_AAFS,		///	AAFS (Activate Arabic form shaping)
+	ID_INSERT_IAFS,		///	IAFS (Inhibit Arabic form shaping)
+*/	ID_INSERT_RS,		///	RS (Record Separator)
+	ID_INSERT_US,		///	US (Unit Separator)
+
+	ID_INSERT_U0020,	///	U+0020 (Space)
+	ID_INSERT_NBSP,		///	NBSP (No-Break Space)
+	ID_INSERT_U1680,	///	U+1680 (Ogham Space Mark)
+	ID_INSERT_MVS,		///	MVS (Mongolian Vowel Separator)
+	ID_INSERT_U2000,	///	U+2000 (En Quad)
+	ID_INSERT_U2001,	///	U+2001 (Em Quad)
+	ID_INSERT_U2002,	///	U+2002 (En Space)
+	ID_INSERT_U2003,	///	U+2003 (Em Space)
+	ID_INSERT_U2004,	///	U+2004 (Three-Per-Em Space)
+	ID_INSERT_U2005,	///	U+2005 (Four-Per-Em Space)
+	ID_INSERT_U2006,	///	U+2006 (Six-Per-Em Space)
+	ID_INSERT_U2007,	///	U+2007 (Figure Space)
+	ID_INSERT_U2008,	///	U+2008 (Punctuation Space)
+	ID_INSERT_U2009,	///	U+2009 (Thin Space)
+	ID_INSERT_U200A,	///	U+200A (Hair Space)
+	ID_INSERT_ZWSP,		///	ZWSP (Zero Width Space)
+	ID_INSERT_NNBSP,	///	NNSBP (Narrwow No-Break Space)
+	ID_INSERT_MMSP,		///	MMSP (Medium Mathematical Space)
+	ID_INSERT_U3000,	///	U+3000 (Ideographic Space)
+	ID_INSERT_NEL,		///	NEL (Next Line)
+	ID_INSERT_LS,		///	LS (Line Separator)
+	ID_INSERT_PS,		///	PS (Paragraph Separator)
+};
 
 // ^C} ID
 ///	}EXhbOőI͈͂ύX
@@ -393,20 +408,6 @@ const EditViewOption	EVO_IGNORECASE				= 0x0100;
 ///	L[{[hŃLbgړłȂ̑OɃ}EXňړł悤ɂ
 const EditViewOption	EVO_ACCEPTABLECARETBYMOUSE	= 0x0200;
 
-///	tO
-typedef unsigned short	EditViewFindFlag;
-///	O
-const EditViewFindFlag	EVF_FORWARD				= 0x00;
-///	
-const EditViewFindFlag	EVF_BACKWARD			= 0x01;
-///	PP
-const EditViewFindFlag	EVF_WHOLEWORD			= 0x02;
-///	啶ʂȂ
-const EditViewFindFlag	EVF_IGNORECASE			= 0x04;
-///	ЉʂȂ
-const EditViewFindFlag	EVF_IGNOREKANATYPE		= 0x08;
-///	K\ (ȊÕtO͖)
-const EditViewFindFlag	EVF_REGULAREXPRESSION	= 0x20;
 
 ///	CEditView ̐ݒ荀
 struct TEditViewOption {
@@ -542,18 +543,23 @@ private:
 /**
  *	@brief	Ascension eLXgGfB^̃r[
  *
- *	̃AvP[Vɑgݍ݂ꍇ CEditController gΊy`B
  *	<h3>KvpA</h3>
+ *
  *	<ul>
- *		<li>̃NXł OLE hbOAhhbvgp̂
- *	gݍ݃AvP[V OleInitialze API ĂяoĂKvB</li>
+ *		<li>̃NXł OLE hbOAhhbvgp̂ŁA
+ *	gݍ݃AvP[VXbh OleInitialze API ĂяoĂKvB</li>
  *		<li>̓\yуC^[tFCX͑S Unicode gp邽߁A
  *	 Windows NT n݂̂ƂȂB</li>
  *		<li>̃NX͌_ł̓XbhZ[tł<strong>Ȃ</strong>B</li>
  *		<li> Unicode 4.0 ̒`ɂ͏]ĂȂB</li>
  *	</ul>
+ *
+ *	eLXgGfB^ƂĎgꍇ CEditView ACEditDoc CX^X𒼐ڂA
+ *	CEditController gق悢
+ *
  *	<h3>p</h3>
- *	<p>̃NXŎgpP̒`͈ȉ̂Ƃ:</p>
+ *
+ *	̃NXŎgpP̒`͈ȉ̂Ƃ:
  *	<dl>
  *		<dt>AJ[|Cg</dt><dd>IJn_BLbg</dd>
  *		<dt>ANeBu|Cg</dt><dd>II_BLbg</dd>
@@ -563,25 +569,30 @@ private:
  *		<dt>NCAgW (Pos)</dt><dd>CEditView EBhE̍オ_</dd>
  *		<dt>r[W</dt><dd>NCAgW + (ѕ + ], э + ])BXN[͖</dd>
  *	</dl>
+ *
  *	<h3>Rs[RXgN^ɂ镡ɂ (To deriver)</h3>
- *	<p>CEditView ̑cNX͑SăRs[RXgN^ĂA
+ *
+ *	CEditView ̑cNX͑SăRs[RXgN^ĂA
  *	̃NXłRs[RXgN^găr[𕡐邱Ƃo (
  *	cNXƓlEBhE͍쐬Ȃ)Bf[^oɑ
- *	̃NX͈ꕔ̃o𕡐ƕŋLB</p>
- *	<p>̓Rs[RXgN^̉EӂŁALf[^o<strong>L</strong>B
+ *	̃NX͈ꕔ̃o𕡐ƕŋL
+ *
+ *	̓Rs[RXgN^̉EӂŁALf[^o<strong>L</strong>B
  *	LȂr[폜ĂLf[^͔jȂA
  *	Lr[폜ƁAL͂̃r[畡ꂽ̃r[ɈڂB
  *	čŌɎcr[폜ꂽƂALf[^͔j󂳂B
  *	̂߃Rs[RXgN^ł͕̃r[A
  *	̃r[IWĩr[LB܂A
- *	r[͎j󂳂ꂽƂɃIWiɒʒmB</p>
- *	<p>܂ALێr[͎ɑ΂ݒ̍XV𑼂̃r[ɒʒmƂڂB
+ *	r[͎j󂳂ꂽƂɃIWiɒʒm
+ *
+ *	܂ALێr[͎ɑ΂ݒ̍XV𑼂̃r[ɒʒmƂڂB
  *	NCAgr[̖{IłȂݒ (tHgsԊuAAvP[V`sȂ)
  *	Lr[ɑ΂čsƁAIɕ̃r[ɂf̂ŁA
- *	NCAg͂֘ASẴr[ݒ肷Kv͖B</p>
- *	<p>CEditController NXŕsꍇ2̃r[͂̕[ɏ]B
+ *	NCAg͂֘ASẴr[ݒ肷Kv͖
+ *
+ *	CEditController NXŕsꍇ2̃r[͂̕[ɏ]B
  *	L̂͊{Iɍŏ̃r[ANX GetPrimaryView
- *	\bhŊmɏLr[擾łB</p>
+ *	\bhŊmɏLr[擾ł
  *
  *	@see	CEditDoc, CEditController
  */
@@ -605,18 +616,19 @@ class CEditView :
 	friend class CEditController;
 	friend class CLineLayoutManager;
 	friend class CEditPoint;
-	friend class CEditRange;
 	friend class CAutoCompleteWnd;
 
 	// f[^o
 private:
 	static bool								m_bRegistered;		// EBhENX̓o^tO
 	static CClipboardRing					m_oClipboardRing;	// Nbv{[hO
+	static CTextSearcher					m_oTextSearcher;	// eLXg
 	static CPopupMenu						m_oContextMenu;		// ftHg̃ReLXgj[
 	Armaiti::OLE::CDraggingTextDataObject*	m_pDragging;		// OLE hbOIuWFNg
 	CKeyMacroPlayer*						m_pKeyMacroPlayer;	// L[}N̊Ǘ
 	CAutoCompleteWnd*						m_pwndAutoComplete;	// ͕⊮EBhE
 	IEditViewEventListener*					m_pEventListener;	// CxgXi
+	std::set<CEditPoint*>					m_setEditPoints;	// ێĂҏW_
 
 	/* LÂ̊Ǘ (NX̐Q) */
 	CEditView*		m_pOriginalView;		//  (null łΎ)
@@ -659,7 +671,7 @@ private:
 
 	/* [h */
 	struct TEditViewModeState {
-		bool			bOverwrite;			// ㏑[h
+		bool			bOvertype;			// ㏑[h
 		bool			bShowUnicodeCtrls;	// Unicode 䕶\邩ǂ ()
 		bool			bBoxSelecting;		// `I ({^ĂȂĂ悢)
 		bool			bCaretMarkByMouse;	// Lbg󂯎Ȃ̑OɃ}EXňړł
@@ -670,7 +682,7 @@ private:
 		AutoIndentType	aitAutoIndentType;	// Cfg̎
 		unsigned long	cFindLimit;			// X}[gCfggpɉsO܂ł̊ʂɑΉ邩
 
-		TEditViewModeState() : bOverwrite(false), bShowUnicodeCtrls(false), bBoxSelecting(false),
+		TEditViewModeState() : bOvertype(false), bShowUnicodeCtrls(false), bBoxSelecting(false),
 			bCaretMarkByMouse(false), lttTabType(LTT_LINENUMBER), wpmWrapMode(WPM_NONE), nWrapWidth(100),
 			bUseOLEDragDrop(true), aitAutoIndentType(AIT_BLOCK), cFindLimit(100) {
 		}
@@ -732,7 +744,7 @@ private:
 		CKeywordManager*	pKeywords1;				// \L[[h1̃Xg
 		CKeywordManager*	pKeywords2;				// \L[[h2̃Xg
 		OperatorMap			mapOperators;			// Zq
-		xstring				strCharsTreatedAsAlpha;	// L[[h\ƂĎgXg
+		std::list<ulong>	listCharsTreatedAsAlpha;// L[[h\ƂĎgXg
 		bool				bLockedParsing;			// s͂}Ă邩 (LockParsing Q)
 
 		TEditViewFoundationInfo();
@@ -836,34 +848,35 @@ public:
 	void	UnlockParsing();												// s̗͂}
 
 	// Lbg
-	void	GetSel(CCharPos& posBegin, CCharPos& posEnd) const;				// I͈͂̎擾
-	bool	HasSelection() const;											// I͈͂邩ǂ
-	void	RecreateCaret();												// Lbg쐬
-	void	SetSel(const CCharPos& posAnchor, const CCharPos& posActive,	// I͈͂̐ݒ
-				bool bScroll = true, bool bRepaint = true);
-	void	SetSelWithoutSelection(const CCharPos& pos,						// Lbgʒu̐ݒ
-				bool bScroll = true, bool bRepaint = true);
-	void	SetSelWithoutSelection(unsigned int iLine, unsigned int iChar,
-				 bool bScroll = true, bool bRepaint = true);
+	CCharPos	GetActivePoint() const;
+	CCharPos	GetAnchorPoint() const;
+	void		GetSel(CCharPos& posAnchor, CCharPos& posActive) const;			// I͈͂̎擾
+	bool		HasSelection() const;											// I͈͂邩ǂ
+	void		RecreateCaret();												// Lbg쐬
+	void		SetSel(const CCharPos& posAnchor, const CCharPos& posActive,	// I͈͂̐ݒ
+					bool bScroll = true, bool bRepaint = true);
+	void		SetSelWithoutSelection(const CCharPos& pos,						// Lbgʒu̐ݒ
+					bool bScroll = true, bool bRepaint = true);
+	void		SetSelWithoutSelection(unsigned int iLine, unsigned int iChar,
+					bool bScroll = true, bool bRepaint = true);
 
 	// ƒu
-	unsigned long	BookmarkAll(const std::wstring& strText, EditViewFindFlag evfFlags);	// Să}[N
-	bool			FindNext(const std::wstring& strText, EditViewFindFlag evfFlags);		// /O
-	unsigned long	ReplaceAll(const std::wstring& strFindWhat,								// SĒu
-						const std::wstring& strReplaceWith, EditViewFindFlag evfFlags);
-	bool			ReplaceAndFindNext(const std::wstring& strFindWhat,						// uĎ
-						const std::wstring& strReplaceWith, EditViewFindFlag evfFlags);
+	unsigned long	BookmarkAll(const std::wstring& strText, SearchFlag sfFlag);	// Să}[N
+	bool			FindNext(const std::wstring& strText, SearchFlag sfFlags);		// /O
+	unsigned long	ReplaceAll(const std::wstring& strFindWhat,						// SĒu
+						const std::wstring& strReplaceWith, SearchFlag sfFlag);
+	bool			ReplaceAndFindNext(const std::wstring& strFindWhat,				// uĎ
+						const std::wstring& strReplaceWith, SearchFlag sfFlag);
 
 	// eLXg
-	static CClipboardRing&	GetClipboardRing();					// Nbv{[hO擾
-	std::wstring			GetNearestWordFromCaret() const;	// Lbgt߂̒P擾
-	std::wstring			GetNearestWordFromCursor() const;	// J[\t߂̒P擾
-	std::wstring			GetPrecedingWord() const;			// Lbg̍ɂP擾
-	std::wstring			GetSelection() const;				// I͈͂̎̕擾
+	static CClipboardRing&	GetClipboardRing();								// Nbv{[hO擾
+	std::wstring			GetNearestWordFromCaret() const;				// Lbgt߂̒P擾
+	std::wstring			GetNearestWordFromCursor() const;				// J[\t߂̒P擾
+	std::wstring			GetPrecedingWord(unsigned long cchLimit) const;	// Lbg̒OɂP擾
+	std::wstring			GetSelection() const;							// I͈͂̎̕擾
 
-	// Cӂ̈ʒu
-	CEditPoint*	CreateEditPoint(const CCharPos& pos);
-	CEditRange*	CreateRange(const CCharPos& posStart, const CCharPos& posEnd);
+	// ҏW_
+	CEditPoint*	CreateEditPoint();
 
 	// ubN}[N
 	void	ClearBookmarks();												// ubN}[NSĉ
@@ -961,13 +974,13 @@ public:
 	virtual CEditDoc*	GetDocument() const;	// hLgIuWFNgւ̃ANZX
 
 	// [h
-	KeyMacroState		GetKeyMacroState() const;					// L[}N̏ԂԂ
-	static CEditView*	GetViewKeyMacroRecording();					// L[}NL^/ꎞ~̃r[Ԃ
-	WrapMode			GetWrapMode() const;						// ܂Ԃ[hԂ
-	bool				IsOverwriteMode() const;					// ㏑[hǂԂ
-	void				SetOverwriteMode(bool bOverwrite = true);	// ㏑[h̐ݒ
-	void				SetWrapMode(WrapMode wpm);					// ܂Ԃ[h̐ݒ
-	void				SetWrapWidth(unsigned long nWrapWidth);		// ܂Ԃ̐ݒ
+	KeyMacroState		GetKeyMacroState() const;				// L[}N̏ԂԂ
+	static CEditView*	GetViewKeyMacroRecording();				// L[}NL^/ꎞ~̃r[Ԃ
+	WrapMode			GetWrapMode() const;					// ܂Ԃ[hԂ
+	bool				IsOvertypeMode() const;					// ㏑[hǂԂ
+	void				SetOvertypeMode(bool bOvertype = true);	// ㏑[h̐ݒ
+	void				SetWrapMode(WrapMode wpm);				// ܂Ԃ[h̐ݒ
+	void				SetWrapWidth(unsigned long nWrapWidth);	// ܂Ԃ̐ݒ
 
 	// IUnknown C^[tFCX
 	IMPLEMENT_UNKNOWN()
@@ -1013,14 +1026,19 @@ protected:
 	static unsigned long	IsWhiteSpace(const wchar_t* psz, unsigned long cch);		// 󔒗ނ
 	static unsigned long	IsURIString(const wchar_t* psz, unsigned long cch);			// URI 
 	bool			CharIsInCommentOrQuotation(const CCharPos& pos) const;				// Rgp
-	static bool		IsCharAcceptableCaret(unsigned long nCodePoint);
-	unsigned long	IsWord(const wchar_t* psz, unsigned long cch) const;				// P
+	unsigned long	IsIdentifier(const wchar_t* psz, unsigned long cch) const;			// ʎq
 	bool			IsSComment1(const wchar_t* psz, unsigned long cch) const;			// PsRg1T
 	bool			IsSComment2(const wchar_t* psz, unsigned long cch) const;			// PsRg2T
 	unsigned long	IsMComment1(const wchar_t* psz, unsigned long cch, bool& bContinued) const;	// sRg1T
 	unsigned long	IsMComment2(const wchar_t* psz, unsigned long cch, bool& bContinued) const;	// sRg2T
 	unsigned long	IsOperator(const wchar_t* psz, unsigned long cch) const;			// Zq
 	unsigned char	IsInvalidCharacter(const wchar_t* psz, unsigned long cch) const;	// sȕ
+
+	// J[eBeB ()
+protected:
+	static bool	IsCharAcceptableCaret(unsigned long nCodePoint);
+	static bool	IsIdentifierContinueChar(unsigned long nCodePoint);
+	static bool	IsIdentifierStartChar(unsigned long nCodePoint);
 				
 	// J[eBeB (`)
 protected:
@@ -1040,17 +1058,14 @@ protected:
 						bool bIgnoreMark, bool* pbTruncated = 0) const;
 	unsigned int	GetAvgCharWidth() const;										// 1̕ϕԂ
 	unsigned long	GetNextTabStop(unsigned long xView, bool bRtlReading) const;	// ̃^uʒuԂ
-	int				MakeCaretPosValid(const wchar_t* pwsz, unsigned long cch,		// LbgʒȕC
-						unsigned long nCaretPos, bool bBackward) const;
+	static int		MakeCaretPosValid(const wchar_t* pwsz,							// LbgʒȕC
+						unsigned long cch, unsigned long nCaretPos, bool bBackward);
 
 	// J[eBeB (̑)
 protected:
 	virtual int		CompareString(const wchar_t* psz1,
 						const wchar_t* psz2, unsigned long cch) const;				// ̔r
 	virtual bool	FindBracket(const CCharPos& pos, CCharPos& posFound) const;		// Ίʂ
-	virtual bool	FindTextInternal(unsigned long iLine, unsigned long iChar,		// 1s猟
-						const std::wstring& strText, EditViewFindFlag evf,
-						unsigned long* piFound = 0, unsigned long* pcchFound = 0) const;
 	unsigned int	GetLineNumberMaxDigit() const;									// s̍ő包Ԃ
 	void			InitializeWindow();
 	void			InsertBoxText(const CCharPos& pos,								// `̑}
@@ -1067,12 +1082,10 @@ protected:
 	// J[eBeB (̑) ʂɌJ
 public:
 	virtual void	DrawUnderline(int x1, int x2, int y, UnderlineType ult);		// 
-	virtual bool	SearchUsingRegExp(const std::wstring& strTarget,				// K\s
-						const std::wstring& strPattern, bool bReverse,
-						bool bIgnoreCase, size_t& iFound, size_t& cchFound);
 
 protected:
 	virtual LRESULT	DispatchEvent(UINT message, WPARAM wParam, LPARAM lParam);
+	void			ReleaseEditPoint(CEditPoint& pt);
 
 	// bZ[Wnh
 protected:
@@ -1133,19 +1146,55 @@ inline UINT CEditView::CanPaste() const {
 inline bool CEditView::CharIsInCommentOrQuotation(const CCharPos& pos) const {
 	AssertValid();
 
-	const TokenList&			listTokens = m_pLineLayoutManager->GetLine(pos.m_iLine)->GetTokenList();
-	TokenList::const_iterator	itTokens = listTokens.begin();
+	const CLineLayoutInfo*		pLine = m_pLineLayoutManager->GetLine(pos.m_iLine);
+	const TokenList&			listTokens = pLine->GetTokenList();
+	TokenList::const_iterator	itTokens = listTokens.end();
+	TextType					ttType;
 
-	for(; itTokens != listTokens.end(); ++itTokens) {
+	// pos s̏ꍇ
+	ttType = (--itTokens)->GetType();
+	if(ttType == TT_COMMENT) {
+		const wstring&	strLine = GetDocument()->GetLine(pos.m_iLine);
+		if(pos.m_iChar == strLine.length())
+			return pLine->GetMultilineCommentStatus(true) != MCT_NOTCOMMENT;
+	} else if(ttType == TT_DOUBLEQUOTATION || ttType == TT_SINGLEQUOTATION) {
+		const wstring&	strLine = GetDocument()->GetLine(pos.m_iLine);
+		if(pos.m_iChar == strLine.length()) {
+			if(itTokens->GetStringLength() == 1)
+				return true;
+			return (ttType == TT_DOUBLEQUOTATION
+					&& strLine[pos.m_iChar - 1] == L'\"'
+					&& strLine[pos.m_iChar - 2] == L'\\')
+				|| (ttType == TT_SINGLEQUOTATION
+					&& strLine[pos.m_iChar - 1] == L'\''
+					&& strLine[pos.m_iChar - 2] == L'\\');
+		}
+	}
+
+	for(itTokens = listTokens.begin(); itTokens != listTokens.end(); ++itTokens) {
 		if(pos.m_iChar > itTokens->GetIndex()
 				&& pos.m_iChar < itTokens->GetIndex() + itTokens->GetStringLength()) {
-			TextType	tt = itTokens->GetType();
-			return (tt == TT_COMMENT || tt == TT_DOUBLEQUOTATION || tt == TT_SINGLEQUOTATION);
+			ttType = itTokens->GetType();
+			return ttType == TT_COMMENT
+				|| ttType == TT_DOUBLEQUOTATION
+				|| ttType == TT_SINGLEQUOTATION;
 		}
 	}
 	return false;
 }
 
+///	ANeBu|CgԂ
+inline CCharPos CEditView::GetActivePoint() const {
+	AssertValid();
+	return m_posActive;
+}
+
+///	AJ[|CgԂ
+inline CCharPos CEditView::GetAnchorPoint() const {
+	AssertValid();
+	return m_posAnchor;
+}
+
 /**
  *	ݎgpĂtHg (C^bNłȂ) 
  *	1`悷Ƃ̕ϕԂ
@@ -1234,14 +1283,14 @@ inline void CEditView::GetOption(TEditViewOption& evo) const {
 	if(m_ModeState.bUseOLEDragDrop)						misc |= EVO_USE_OLEDRAGDROP;
 
 	std::wostringstream	ssChars;
-	const xstring&		strAlpha = m_FoundationInfo.strCharsTreatedAsAlpha;
+	const list<ulong>&	listAlphas = m_FoundationInfo.listCharsTreatedAsAlpha;
 	wchar_t				wszSurrogates[3] = {0, 0, 0};
-	for(xstring::size_type i = 0; i < strAlpha.length(); ++i) {
-		if(strAlpha[i] >= 0x010000) {
-			Manah::CTextConverter::EncodeCodePointToUTF16SurrogatePair(strAlpha[i], wszSurrogates);
+	for(list<ulong>::const_iterator it = listAlphas.begin(); it != listAlphas.end(); ++it) {
+		if(*it >= 0x010000) {
+			Manah::CTextConverter::EncodeCodePointToUTF16SurrogatePair(*it, wszSurrogates);
 			ssChars << wszSurrogates;
 		} else
-			ssChars << static_cast<wchar_t>(strAlpha[i]);
+			ssChars << static_cast<wchar_t>(*it);
 	}
 	evo.strCharsTreatedAsAlpha = ssChars.str();
 }
@@ -1371,6 +1420,36 @@ inline unsigned long CEditView::IsDoubleQuotation(const wchar_t* psz, unsigned l
 	return cch;
 }
 
+/**
+ *	ʎq̒Ԃ
+ *	@param psz	ׂ镶
+ *	@param cch	
+ *	@return		ʎq\AĂ钷BʎqłȂ0
+ *	@see		CEditView::IsIdentifierContinueChar,
+ *				CEditView::IsIdentifierStartChar
+ */
+inline unsigned long CEditView::IsIdentifier(const wchar_t* psz, unsigned long cch) const {
+	assert(psz != 0);
+
+	unsigned long	nCodePoint;
+	for(unsigned long i = 0; i < cch; ++i) {
+		if(Manah::CTextConverter::IsUTF16HighSurrogate(psz[i])
+				&& i < cch - 1
+				&& Manah::CTextConverter::IsUTF16LowSurrogate(psz[i + 1]))
+			nCodePoint = Manah::CTextConverter::DecodeUTF16SurrogatePairToCodePoint(psz + i, cch - i);
+		else
+			nCodePoint = psz[i];
+		if((i == 0 && CEditView::IsIdentifierStartChar(nCodePoint))
+				|| CEditView::IsIdentifierContinueChar(nCodePoint)) {
+			if(nCodePoint >= 0x010000)
+				++i;
+			continue;
+		}
+		return i;
+	}
+	return cch;
+}
+
 /**
  *	݂̃R[hy[Wŕsȕ̒Ԃ
  *	@param psz	ׂ镶ւ̃|C^
@@ -1561,11 +1640,11 @@ inline unsigned long CEditView::IsOperator(const wchar_t* psz, unsigned long cch
 
 /**
  *	㏑[hǂԂ
- *	@see	CEditView::SetOverwriteMode
+ *	@see	CEditView::SetOvertypeMode
  */
-inline bool CEditView::IsOverwriteMode() const {
+inline bool CEditView::IsOvertypeMode() const {
 	AssertValid();
-	return m_ModeState.bOverwrite;
+	return m_ModeState.bOvertype;
 }
 
 /**
@@ -1622,102 +1701,6 @@ inline unsigned long CEditView::IsSingleQuotation(const wchar_t* psz, unsigned l
 	return cch;
 }
 
-/**
- *	󔒗ޕ̒Ԃ
- *	@param psz	ׂ镶
- *	@param cch	
- *	@return		󔒗ޕAĂ钷BzCgXy[XłȂ0
- */
-inline unsigned long CEditView::IsWhiteSpace(const wchar_t* psz, unsigned long cch) {
-	assert(psz != 0);
-
-	for(unsigned long i = 0; i < cch; ++i) {
-		if(!iswspace(*(psz+i)))
-			return i;
-	}
-	return cch;
-}
-
-/**
- *	P̒Ԃ
- *	@param psz	ׂ镶
- *	@param cch	
- *	@return		P\AĂ钷BPłȂ0
- */
-inline unsigned long CEditView::IsWord(const wchar_t* psz, unsigned long cch) const {
-	assert(psz != 0);
-
-	WORD			w;
-	unsigned long	ch;
-	for(unsigned long i = 0; i < cch; ++i) {
-		if(Manah::CTextConverter::IsUTF16HighSurrogate(*(psz + i))
-				&& i < cch - 1
-				&& Manah::CTextConverter::IsUTF16LowSurrogate(*(psz + i + 1))) {
-			ch = Manah::CTextConverter::DecodeUTF16SurrogatePairToCodePoint(psz + i, cch - i);
-			if(m_FoundationInfo.strCharsTreatedAsAlpha.find(ch) != xstring::npos)
-				++i;
-			else if((ch >= 0x010000 && ch <= 0x01004D)		// Linear B Syllabary
-					|| (ch >= 0x010080 && ch <= 0x0100FA)	// Linear B Ideograms
-					|| (ch >= 0x010300 && ch <= 0x01031E)	// Old Italic
-					|| (ch >= 0x010330 && ch <= 0x010349)	// Gothic
-					|| (ch >= 0x010380 && ch <= 0x01039D)	// Ugaritic
-					|| (ch >= 0x010400 && ch <= 0x01044F)	// Diseret
-					|| (ch >= 0x010450 && ch <= 0x01047F)	// Shavian
-					|| (ch >= 0x010480 && ch <= 0x01049D)	// Osmanya
-					|| (ch >= 0x010800 && ch <= 0x01083C)	// Cypriot
-					|| (ch == 0x01083F)
-					|| (ch >= 0x01D400 && ch <= 0x01D454)	// Mathematical Alphanumeric Symbols
-					|| (ch >= 0x01D456 && ch <= 0x01D49C)
-					|| (ch == 0x01D49E)
-					|| (ch == 0x01D49F)
-					|| (ch == 0x01D4A2)
-					|| (ch == 0x01D4A5)
-					|| (ch == 0x01D4A6)
-					|| (ch >= 0x01D4A9 && ch <= 0x01D4AC)
-					|| (ch >= 0x01D4AE && ch <= 0x01D4B9)
-					|| (ch == 0x01D4BB)
-					|| (ch >= 0x01D4BD && ch <= 0x01D4C3)
-					|| (ch >= 0x01D4C5 && ch <= 0x01D505)
-					|| (ch >= 0x01D507 && ch <= 0x01D50A)
-					|| (ch >= 0x01D50D && ch <= 0x01D514)
-					|| (ch >= 0x01D516 && ch <= 0x01D51C)
-					|| (ch >= 0x01D51E && ch <= 0x01D539)
-					|| (ch >= 0x01D53B && ch <= 0x01D53E)
-					|| (ch >= 0x01D540 && ch <= 0x01D544)
-					|| (ch == 0x01D546)
-					|| (ch >= 0x01D54A && ch <= 0x01D550)
-					|| (ch >= 0x01D552 && ch <= 0x01D7C9)
-					|| (ch >= 0x020000 && ch <= 0x02A6D6)	// CJK Unified Ideographs Extension B
-					|| (ch >= 0x02F800 && ch <= 0x02FA1D)	// CJK Compatibility Ideographs Supplement
-					|| (ch >= 0x0E0041 && ch <= 0x0E005A)	// Tags
-					|| (ch >= 0x0E0061 && ch <= 0x0E007A))
-				++i;
-			else if((i != 0) && (	// 
-					(ch >= 0x010107 && ch <= 0x010133)		// Aegean Numbers
-					|| (ch >= 0x010320 && ch <= 0x010323)	// Old Italic
-					|| (ch >= 0x0104A0 && ch <= 0x0104A9)	// Osmanya
-					|| (ch >= 0x01D7CE && ch <= 0x01D7FF)	// Mathematical Alphanumeric Symbols
-					|| (ch >= 0x0E0030 && ch <= 0x0E0039)))	// Tags
-				++i;
-			else
-				return i;
-		} else if(m_FoundationInfo.strCharsTreatedAsAlpha.find(psz[i]) != xstring::npos)
-			continue;
-		else {
-			::GetStringTypeW(CT_CTYPE3, psz + i, 1, &w);
-			if(!toBoolean(w & (C3_DIACRITIC | C3_VOWELMARK | /*C3_LEXICAL |*/ C3_ALPHA))) {
-				if(i != 0) {
-					::GetStringTypeW(CT_CTYPE1, psz + i, 1, &w);
-					if(!toBoolean(w & C1_DIGIT))
-						return i;
-				} else
-					return i;
-			}
-		}
-	}
-	return cch;
-}
-
 } // namespace Ascension
 
 #endif /* _EDIT_VIEW_H_ */
