@@ -624,7 +624,7 @@ void CLineLayoutManager::ParseLineTokens(unsigned long iLine, CLineLayoutInfo* p
 		else if(m_pView->m_layoutInfo.tfTextFoundation[TT_SINGLEQUOTATION].enabled
 				&& 0 != (oToken.m_cchToken = m_pView->IsSingleQuotation(pwszLine + iChar, cchLine - iChar)))	// dp
 			oToken.m_ttType = TT_SINGLEQUOTATION;
-		else if(0 != (oToken.m_cchToken = m_pView->IsWord(pwszLine + iChar, cchLine - iChar))) {	// Pꂩ
+		else if(0 != (oToken.m_cchToken = m_pView->IsIdentifier(pwszLine + iChar, cchLine - iChar))) {	// Pꂩ
 			if(m_pView->m_layoutInfo.tfTextFoundation[TT_KEYWORD1].enabled
 					&& m_pView->m_FoundationInfo.pKeywords1->Find(pwszLine + iChar,
 					oToken.m_cchToken, m_pView->m_FoundationInfo.bIgnoreCaseOnHilite))	// \L[[h1
